#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_RROR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_RROR_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/scalar/rror.hpp>

#endif
